@@ -1,6 +1,6 @@
 #!/usr/bin/env python3
 
-# Copyright (c) 2021, harens
+# Copyright (c) 2022, harens
 #
 # All rights reserved.
 #
@@ -51,12 +51,6 @@ class Port:
         >>> port.version
         '1.0.1'
 
-        >>> # Same as above, but uses `port info` rather than `port info --index`
-        >>> from seaport.portfile import Port
-        >>> port = Port("py-base91", True)
-        >>> port.version
-        '1.0.1'
-
         >>> from seaport.portfile import Port
         >>> try:
         ...     port = Port("non-existent-port")
@@ -66,7 +60,6 @@ class Port:
 
     Attributes:
         name (str): The name of the port e.g. gping
-        careful (bool): Defaults to false. Use if portfiles are being edited frequently (not required if only reading).
     """
 
     # This makes mypy and pytype happy
@@ -75,27 +68,27 @@ class Port:
     version: str
 
     @beartype
-    def __init__(self, name: str, careful: bool = False) -> None:
+    def __init__(self, name: str) -> None:
         """Set optional attributes and check if port exists."""
         # TODO: Figure out how to find path without subprocess
         # TODO: Refactor this
         # TODO: This also kind of defeats the purpose of that bandit error, so find a better way to determine the path
         # no forward slash at end for Bandit B607
         self.name = name
-        self._index = careful
         self._path = format_subprocess(["/usr/bin/which", "port"]).replace("/port", "")
 
+        # TODO: We're calling port info twice (here and in _index()). Maybe find a way to only do it once.
         try:
-            if self._index:
-                self._info = format_subprocess(
-                    [f"{self._path}/port", "info", self.name]
-                )
-            else:
+            if self._index():
                 # Caches port info for later
                 # --index provides big speed boost, but doesn't always work
                 self._info = format_subprocess(
                     [f"{self._path}/port", "info", "--index", self.name]
                 )
+            else:
+                self._info = format_subprocess(
+                    [f"{self._path}/port", "info", self.name]
+                )
         except subprocess.CalledProcessError:
             # TODO: Set a more specific exception
             raise Exception(f"{self.name} doesn't exist, run portindex if port is new")
@@ -103,15 +96,14 @@ class Port:
         self.version = self.__current()
 
     @beartype
-    def __repr__(self) -> str:
-        """Outputs the arguments of the init class (i.e. name and careful mode).
+    def _index(self) -> bool:
+        """Whether to use the --index flag with port or not.
 
-        Examples:
-            >>> from seaport.portfile import Port
-            >>> Port("py-base91")
-            Port('py-base91', False)
+        --index provides a speed boost, but can be wrong if the port has been edited recently.
         """
-        return f"{self.__class__.__name__}(" f"{self.name!r}, {self._index!r})"
+        return format_subprocess(
+            [f"{self._path}/port", "info", self.name]
+        ) == format_subprocess([f"{self._path}/port", "info", "--index", self.name])
 
     @beartype
     def __str__(self) -> str:
@@ -142,7 +134,7 @@ class Port:
         # Be careful of revision numbers e.g. 1.2.3_1
         # Credit to https://stackoverflow.com/a/29836831/10763533
         # return self._info[self._info.find("@") + 1 :].split()[0]
-        if self._index:
+        if self._index():
             return format_subprocess(
                 [f"{self._path}/port", "info", "--version", "--index", self.name]
             ).split(" ")[1]
@@ -286,16 +278,10 @@ class Port:
             >>> port.primary_category()
             'net'
 
-            >>> from seaport.portfile import Port
-            >>> port = Port("py-rich")
-            >>> port.primary_category()
-            'python'
-
-
         Returns:
             The category of the port e.g. sysutils.
         """
-        if self._index:
+        if self._index():
             category_list = format_subprocess(
                 [f"{self._path}/port", "info", "--index", "--category", self.name]
             ).split(" ")
